package cn.com.infosec.jce.netscape;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.KeyFactory;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.Signature;
import java.security.SignatureException;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.X509EncodedKeySpec;

public class NetscapeCertRequest extends ASN1Encodable {
   AlgorithmIdentifier sigAlg;
   AlgorithmIdentifier keyAlg;
   byte[] sigBits;
   String challenge;
   DERBitString content;
   PublicKey pubkey;

   private static ASN1Sequence getReq(byte[] r) {
      return ASN1Sequence.getInstance((new ASN1InputStream(new ByteArrayInputStream(r))).readObject());
   }

   public NetscapeCertRequest(byte[] req) {
      this(getReq(req));
   }

   public NetscapeCertRequest(ASN1Sequence spkac) {
      ASN1Sequence var10000 = spkac;
      super();

      Exception var17;
      label86: {
         boolean var10001;
         int var18;
         try {
            var18 = var10000.size();
         } catch (Exception var12) {
            var17 = var12;
            var10001 = false;
            break label86;
         }

         StringBuffer var21;
         StringBuffer var24;
         IllegalArgumentException var25;
         IllegalArgumentException var26;
         if (var18 == 3) {
            label90: {
               try {
                  this.sigAlg = new AlgorithmIdentifier((ASN1Sequence)spkac.getObjectAt(1));
                  this.sigBits = ((DERBitString)spkac.getObjectAt(2)).getBytes();
                  var10000 = (ASN1Sequence)spkac.getObjectAt(0);
               } catch (Exception var9) {
                  var17 = var9;
                  var10001 = false;
                  break label90;
               }

               spkac = var10000;

               try {
                  var18 = var10000.size();
               } catch (Exception var8) {
                  var17 = var8;
                  var10001 = false;
                  break label90;
               }

               if (var18 == 2) {
                  label91: {
                     SubjectPublicKeyInfo var10002;
                     NetscapeCertRequest var19;
                     NetscapeCertRequest var22;
                     try {
                        var22 = this;
                        var19 = this;
                        this.challenge = ((DERIA5String)spkac.getObjectAt(1)).getString();
                        this.content = new DERBitString(spkac);
                        var10002 = new SubjectPublicKeyInfo;
                     } catch (Exception var5) {
                        var17 = var5;
                        var10001 = false;
                        break label91;
                     }

                     SubjectPublicKeyInfo var13;
                     SubjectPublicKeyInfo var10003 = var13 = var10002;

                     X509EncodedKeySpec var23;
                     try {
                        var10003.<init>((ASN1Sequence)spkac.getObjectAt(0));
                        var23 = new X509EncodedKeySpec;
                     } catch (Exception var4) {
                        var17 = var4;
                        var10001 = false;
                        break label91;
                     }

                     X509EncodedKeySpec spkac1 = var23;

                     AlgorithmIdentifier var20;
                     try {
                        var23.<init>((new DERBitString(var13)).getBytes());
                        var20 = var10002.getAlgorithmId();
                     } catch (Exception var3) {
                        var17 = var3;
                        var10001 = false;
                        break label91;
                     }

                     AlgorithmIdentifier var14 = var20;

                     try {
                        var19.keyAlg = var20;
                        var22.pubkey = KeyFactory.getInstance(var14.getObjectId().getId(), "INFOSEC").generatePublic(spkac1);
                        return;
                     } catch (Exception var2) {
                        var17 = var2;
                        var10001 = false;
                     }
                  }
               } else {
                  label92: {
                     try {
                        var26 = new IllegalArgumentException;
                        var25 = var26;
                        var21 = new StringBuffer;
                     } catch (Exception var7) {
                        var17 = var7;
                        var10001 = false;
                        break label92;
                     }

                     var24 = var21;

                     try {
                        var24.<init>("invalid PKAC (len): ");
                        var25.<init>(var21.append(spkac.size()).toString());
                        throw var26;
                     } catch (Exception var6) {
                        var17 = var6;
                        var10001 = false;
                     }
                  }
               }
            }
         } else {
            label93: {
               try {
                  var26 = new IllegalArgumentException;
                  var25 = var26;
                  var21 = new StringBuffer;
               } catch (Exception var11) {
                  var17 = var11;
                  var10001 = false;
                  break label93;
               }

               var24 = var21;

               try {
                  var24.<init>("invalid SPKAC (size):");
                  var25.<init>(var21.append(spkac.size()).toString());
                  throw var26;
               } catch (Exception var10) {
                  var17 = var10;
                  var10001 = false;
               }
            }
         }
      }

      Exception var15 = var17;
      throw new IllegalArgumentException(var15.toString());
   }

   public NetscapeCertRequest(String challenge, AlgorithmIdentifier signing_alg, PublicKey pub_key) {
      this.challenge = challenge;
      this.sigAlg = signing_alg;
      this.pubkey = pub_key;
      ASN1EncodableVector signing_alg1;
      ASN1EncodableVector var10001 = signing_alg1 = new ASN1EncodableVector;
      signing_alg1.<init>();
      var10001.add(this.getKeySpec());
      var10001.add(new DERIA5String(challenge));
      this.content = new DERBitString(new DERSequence(signing_alg1));
   }

   private DERObject getKeySpec() {
      ByteArrayOutputStream var10000 = new ByteArrayOutputStream;
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10001 = var1 = var10000;
      NetscapeCertRequest var10002 = this;
      var1.<init>();

      try {
         var10001.write(var10002.pubkey.getEncoded());
         var10000.close();
         return (new ASN1InputStream(new ByteArrayInputStream(var1.toByteArray()))).readObject();
      } catch (IOException var2) {
         throw new InvalidKeySpecException(var2.getMessage());
      }
   }

   public String getChallenge() {
      return this.challenge;
   }

   public void setChallenge(String value) {
      this.challenge = value;
   }

   public AlgorithmIdentifier getSigningAlgorithm() {
      return this.sigAlg;
   }

   public void setSigningAlgorithm(AlgorithmIdentifier value) {
      this.sigAlg = value;
   }

   public AlgorithmIdentifier getKeyAlgorithm() {
      return this.keyAlg;
   }

   public void setKeyAlgorithm(AlgorithmIdentifier value) {
      this.keyAlg = value;
   }

   public PublicKey getPublicKey() {
      return this.pubkey;
   }

   public void setPublicKey(PublicKey value) {
      this.pubkey = value;
   }

   public boolean verify(String challenge) {
      if (!challenge.equals(this.challenge)) {
         return false;
      } else {
         Signature challenge1;
         Signature var10000 = challenge1 = Signature.getInstance(this.sigAlg.getObjectId().getId(), "INFOSEC");
         challenge1.initVerify(this.pubkey);
         challenge1.update(this.content.getBytes());
         return var10000.verify(this.sigBits);
      }
   }

   public void sign(PrivateKey priv_key) {
      this.sign(priv_key, (SecureRandom)null);
   }

   public void sign(PrivateKey priv_key, SecureRandom rand) {
      Signature var3 = Signature.getInstance(this.sigAlg.getObjectId().getId(), "INFOSEC");
      if (rand != null) {
         var3.initSign(priv_key, rand);
      } else {
         var3.initSign(priv_key);
      }

      ByteArrayOutputStream priv_key1;
      ByteArrayOutputStream var10003 = priv_key1 = new ByteArrayOutputStream;
      var10003.<init>();
      DEROutputStream var10004 = new DEROutputStream;
      DEROutputStream var10005 = var10004;
      var10004.<init>(priv_key1);
      ASN1EncodableVector priv_key2;
      ASN1EncodableVector var10006 = priv_key2 = new ASN1EncodableVector;
      priv_key2.<init>();
      var10006.add(this.getKeySpec());
      var10006.add(new DERIA5String(this.challenge));

      try {
         var10005.writeObject(new DERSequence(priv_key2));
         var10004.close();
      } catch (IOException var4) {
         throw new SignatureException(var4.getMessage());
      }

      var3.update(var10003.toByteArray());
      this.sigBits = var3.sign();
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      ASN1EncodableVector var2;
      ASN1EncodableVector var10000 = var2 = new ASN1EncodableVector;
      NetscapeCertRequest var10001 = this;
      var2.<init>();

      try {
         var10000.add(var10001.getKeySpec());
      } catch (Exception var3) {
      }

      var2.add(new DERIA5String(this.challenge));
      var1.add(new DERSequence(var2));
      var1.add(this.sigAlg);
      var1.add(new DERBitString(this.sigBits));
      return new DERSequence(var1);
   }
}
